# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_sale_listings200_response_inner_history20240624 import RentcastSaleListings200ResponseInnerHistory20240624

class TestRentcastSaleListings200ResponseInnerHistory20240624(unittest.TestCase):
    """RentcastSaleListings200ResponseInnerHistory20240624 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastSaleListings200ResponseInnerHistory20240624:
        """Test RentcastSaleListings200ResponseInnerHistory20240624
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastSaleListings200ResponseInnerHistory20240624`
        """
        model = RentcastSaleListings200ResponseInnerHistory20240624()
        if include_optional:
            return RentcastSaleListings200ResponseInnerHistory20240624(
                event = 'Sale Listing',
                price = 899000,
                listing_type = 'Standard',
                listed_date = '2024-06-24T00:00:00.000Z',
                removed_date = None,
                days_on_market = 99
            )
        else:
            return RentcastSaleListings200ResponseInnerHistory20240624(
        )
        """

    def testRentcastSaleListings200ResponseInnerHistory20240624(self):
        """Test RentcastSaleListings200ResponseInnerHistory20240624"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
