# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_market_statistics200_response_rental_data import RentcastMarketStatistics200ResponseRentalData

class TestRentcastMarketStatistics200ResponseRentalData(unittest.TestCase):
    """RentcastMarketStatistics200ResponseRentalData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastMarketStatistics200ResponseRentalData:
        """Test RentcastMarketStatistics200ResponseRentalData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastMarketStatistics200ResponseRentalData`
        """
        model = RentcastMarketStatistics200ResponseRentalData()
        if include_optional:
            return RentcastMarketStatistics200ResponseRentalData(
                last_updated_date = '2024-10-14T00:00:00.000Z',
                average_rent = 1521,
                median_rent = 1495,
                min_rent = 750,
                max_rent = 2700,
                average_rent_per_square_foot = 1.38,
                median_rent_per_square_foot = 1.3,
                min_rent_per_square_foot = 0.86,
                max_rent_per_square_foot = 2.59,
                average_square_footage = 1175,
                median_square_footage = 1100,
                min_square_footage = 590,
                max_square_footage = 2100,
                average_days_on_market = 25,
                median_days_on_market = 8,
                min_days_on_market = 1,
                max_days_on_market = 304,
                new_listings = 18,
                total_listings = 76,
                data_by_property_type = [
                    rentcast_client.models.market_statistics_200_response_rental_data_data_by_property_type_inner.market_statistics_200_response_rentalData_dataByPropertyType_inner(
                        property_type = 'Apartment', 
                        average_rent = 1148, 
                        median_rent = 1050, 
                        min_rent = 750, 
                        max_rent = 1975, 
                        average_rent_per_square_foot = 1.23, 
                        median_rent_per_square_foot = 1.13, 
                        min_rent_per_square_foot = 1.03, 
                        max_rent_per_square_foot = 1.59, 
                        average_square_footage = 957, 
                        median_square_footage = 950, 
                        min_square_footage = 650, 
                        max_square_footage = 1560, 
                        average_days_on_market = 17.43, 
                        median_days_on_market = 1, 
                        min_days_on_market = 1, 
                        max_days_on_market = 80, 
                        new_listings = 5, 
                        total_listings = 15, )
                    ],
                data_by_bedrooms = [
                    rentcast_client.models.market_statistics_200_response_rental_data_data_by_bedrooms_inner.market_statistics_200_response_rentalData_dataByBedrooms_inner(
                        bedrooms = 1, 
                        average_rent = 842, 
                        median_rent = 850, 
                        min_rent = 750, 
                        max_rent = 945, 
                        average_rent_per_square_foot = 1.35, 
                        median_rent_per_square_foot = 1.3, 
                        min_rent_per_square_foot = 1.06, 
                        max_rent_per_square_foot = 1.57, 
                        average_square_footage = 679, 
                        median_square_footage = 650, 
                        min_square_footage = 590, 
                        max_square_footage = 800, 
                        average_days_on_market = 27.33, 
                        median_days_on_market = 9, 
                        min_days_on_market = 1, 
                        max_days_on_market = 80, 
                        new_listings = 1, 
                        total_listings = 7, )
                    ],
                history = rentcast_client.models.market_statistics_200_response_rental_data_history.market_statistics_200_response_rentalData_history(
                    2024_08 = rentcast_client.models.market_statistics_200_response_rental_data_history_2024_08.market_statistics_200_response_rentalData_history_2024_08(
                        date = '2024-08-01T00:00:00.000Z', 
                        average_rent = 1496, 
                        median_rent = 1495, 
                        min_rent = 750, 
                        max_rent = 2800, 
                        average_rent_per_square_foot = 1.33, 
                        median_rent_per_square_foot = 1.27, 
                        min_rent_per_square_foot = 0.86, 
                        max_rent_per_square_foot = 2.52, 
                        average_square_footage = 1171, 
                        median_square_footage = 1100, 
                        min_square_footage = 650, 
                        max_square_footage = 2100, 
                        average_days_on_market = 66.49, 
                        median_days_on_market = 16, 
                        min_days_on_market = 1, 
                        max_days_on_market = 365, 
                        new_listings = 39, 
                        total_listings = 96, 
                        data_by_property_type = [
                            rentcast_client.models.market_statistics_200_response_rental_data_history_2024_08_data_by_property_type_inner.market_statistics_200_response_rentalData_history_2024_08_dataByPropertyType_inner(
                                property_type = 'Apartment', 
                                average_rent = 1118, 
                                median_rent = 1050, 
                                min_rent = 750, 
                                max_rent = 1975, 
                                average_rent_per_square_foot = 1.24, 
                                median_rent_per_square_foot = 1.07, 
                                min_rent_per_square_foot = 0.98, 
                                max_rent_per_square_foot = 2.16, 
                                average_square_footage = 922, 
                                median_square_footage = 950, 
                                min_square_footage = 650, 
                                max_square_footage = 1560, 
                                average_days_on_market = 63.82, 
                                median_days_on_market = 17, 
                                min_days_on_market = 1, 
                                max_days_on_market = 365, 
                                new_listings = 8, 
                                total_listings = 23, )
                            ], 
                        data_by_bedrooms = [
                            rentcast_client.models.market_statistics_200_response_rental_data_history_2024_08_data_by_bedrooms_inner.market_statistics_200_response_rentalData_history_2024_08_dataByBedrooms_inner(
                                bedrooms = 1, 
                                average_rent = 953, 
                                median_rent = 825, 
                                min_rent = 750, 
                                max_rent = 1610, 
                                average_rent_per_square_foot = 1.41, 
                                median_rent_per_square_foot = 1.3, 
                                min_rent_per_square_foot = 1.06, 
                                max_rent_per_square_foot = 2.16, 
                                average_square_footage = 732, 
                                median_square_footage = 675, 
                                min_square_footage = 650, 
                                max_square_footage = 950, 
                                average_days_on_market = 33.44, 
                                median_days_on_market = 17, 
                                min_days_on_market = 1, 
                                max_days_on_market = 124, 
                                new_listings = 3, 
                                total_listings = 10, )
                            ], ), 
                    2024_09 = rentcast_client.models.market_statistics_200_response_rental_data_history_2024_09.market_statistics_200_response_rentalData_history_2024_09(
                        date = '2024-09-01T00:00:00.000Z', 
                        average_rent = 1536, 
                        median_rent = 1550, 
                        min_rent = 750, 
                        max_rent = 2800, 
                        average_rent_per_square_foot = 1.38, 
                        median_rent_per_square_foot = 1.33, 
                        min_rent_per_square_foot = 0.86, 
                        max_rent_per_square_foot = 2.52, 
                        average_square_footage = 1180, 
                        median_square_footage = 1120, 
                        min_square_footage = 590, 
                        max_square_footage = 2100, 
                        average_days_on_market = 32.03, 
                        median_days_on_market = 8, 
                        min_days_on_market = 1, 
                        max_days_on_market = 365, 
                        new_listings = 33, 
                        total_listings = 80, ), 
                    2024_10 = rentcast_client.models.market_statistics_200_response_rental_data_history_2024_10.market_statistics_200_response_rentalData_history_2024_10(
                        date = '2024-10-01T00:00:00.000Z', 
                        average_rent = 1521, 
                        median_rent = 1495, 
                        min_rent = 750, 
                        max_rent = 2700, 
                        average_rent_per_square_foot = 1.38, 
                        median_rent_per_square_foot = 1.3, 
                        min_rent_per_square_foot = 0.86, 
                        max_rent_per_square_foot = 2.59, 
                        average_square_footage = 1175, 
                        median_square_footage = 1100, 
                        min_square_footage = 590, 
                        max_square_footage = 2100, 
                        average_days_on_market = 25, 
                        median_days_on_market = 8, 
                        min_days_on_market = 1, 
                        max_days_on_market = 304, 
                        new_listings = 18, 
                        total_listings = 76, ), )
            )
        else:
            return RentcastMarketStatistics200ResponseRentalData(
        )
        """

    def testRentcastMarketStatistics200ResponseRentalData(self):
        """Test RentcastMarketStatistics200ResponseRentalData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
