# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from rentcast_client.models.rentcast_property_records200_response_inner_property_taxes2020 import RentcastPropertyRecords200ResponseInnerPropertyTaxes2020
from rentcast_client.models.rentcast_property_records200_response_inner_property_taxes2021 import RentcastPropertyRecords200ResponseInnerPropertyTaxes2021
from rentcast_client.models.rentcast_property_records200_response_inner_property_taxes2022 import RentcastPropertyRecords200ResponseInnerPropertyTaxes2022
from rentcast_client.models.rentcast_property_records200_response_inner_property_taxes2023 import RentcastPropertyRecords200ResponseInnerPropertyTaxes2023
from rentcast_client.models.rentcast_property_records200_response_inner_property_taxes2024 import RentcastPropertyRecords200ResponseInnerPropertyTaxes2024
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class RentcastPropertyRecords200ResponseInnerPropertyTaxes(BaseModel):
    """
    RentcastPropertyRecords200ResponseInnerPropertyTaxes
    """ # noqa: E501
    var_2020: Optional[RentcastPropertyRecords200ResponseInnerPropertyTaxes2020] = Field(default=None, alias="2020")
    var_2021: Optional[RentcastPropertyRecords200ResponseInnerPropertyTaxes2021] = Field(default=None, alias="2021")
    var_2022: Optional[RentcastPropertyRecords200ResponseInnerPropertyTaxes2022] = Field(default=None, alias="2022")
    var_2023: Optional[RentcastPropertyRecords200ResponseInnerPropertyTaxes2023] = Field(default=None, alias="2023")
    var_2024: Optional[RentcastPropertyRecords200ResponseInnerPropertyTaxes2024] = Field(default=None, alias="2024")
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["2020", "2021", "2022", "2023", "2024"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RentcastPropertyRecords200ResponseInnerPropertyTaxes from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of var_2020
        if self.var_2020:
            _dict['2020'] = self.var_2020.to_dict()
        # override the default output from pydantic by calling `to_dict()` of var_2021
        if self.var_2021:
            _dict['2021'] = self.var_2021.to_dict()
        # override the default output from pydantic by calling `to_dict()` of var_2022
        if self.var_2022:
            _dict['2022'] = self.var_2022.to_dict()
        # override the default output from pydantic by calling `to_dict()` of var_2023
        if self.var_2023:
            _dict['2023'] = self.var_2023.to_dict()
        # override the default output from pydantic by calling `to_dict()` of var_2024
        if self.var_2024:
            _dict['2024'] = self.var_2024.to_dict()
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RentcastPropertyRecords200ResponseInnerPropertyTaxes from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "2020": RentcastPropertyRecords200ResponseInnerPropertyTaxes2020.from_dict(obj["2020"]) if obj.get("2020") is not None else None,
            "2021": RentcastPropertyRecords200ResponseInnerPropertyTaxes2021.from_dict(obj["2021"]) if obj.get("2021") is not None else None,
            "2022": RentcastPropertyRecords200ResponseInnerPropertyTaxes2022.from_dict(obj["2022"]) if obj.get("2022") is not None else None,
            "2023": RentcastPropertyRecords200ResponseInnerPropertyTaxes2023.from_dict(obj["2023"]) if obj.get("2023") is not None else None,
            "2024": RentcastPropertyRecords200ResponseInnerPropertyTaxes2024.from_dict(obj["2024"]) if obj.get("2024") is not None else None
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj


