# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_property_records200_response_inner_owner import RentcastPropertyRecords200ResponseInnerOwner

class TestRentcastPropertyRecords200ResponseInnerOwner(unittest.TestCase):
    """RentcastPropertyRecords200ResponseInnerOwner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastPropertyRecords200ResponseInnerOwner:
        """Test RentcastPropertyRecords200ResponseInnerOwner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastPropertyRecords200ResponseInnerOwner`
        """
        model = RentcastPropertyRecords200ResponseInnerOwner()
        if include_optional:
            return RentcastPropertyRecords200ResponseInnerOwner(
                names = [
                    'Michael Smith'
                    ],
                type = 'Individual',
                mailing_address = rentcast_client.models.property_records_200_response_inner_owner_mailing_address.property_records_200_response_inner_owner_mailingAddress(
                    id = '149-Weaver-Blvd,---264,-Weaverville,-NC-28787', 
                    formatted_address = '149 Weaver Blvd, # 264, Weaverville, NC 28787', 
                    address_line1 = '149 Weaver Blvd', 
                    address_line2 = '# 264', 
                    city = 'Weaverville', 
                    state = 'NC', 
                    zip_code = '28787', )
            )
        else:
            return RentcastPropertyRecords200ResponseInnerOwner(
        )
        """

    def testRentcastPropertyRecords200ResponseInnerOwner(self):
        """Test RentcastPropertyRecords200ResponseInnerOwner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
