# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history202408 import RentcastMarketStatistics200ResponseRentalDataHistory202408

class TestRentcastMarketStatistics200ResponseRentalDataHistory202408(unittest.TestCase):
    """RentcastMarketStatistics200ResponseRentalDataHistory202408 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastMarketStatistics200ResponseRentalDataHistory202408:
        """Test RentcastMarketStatistics200ResponseRentalDataHistory202408
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastMarketStatistics200ResponseRentalDataHistory202408`
        """
        model = RentcastMarketStatistics200ResponseRentalDataHistory202408()
        if include_optional:
            return RentcastMarketStatistics200ResponseRentalDataHistory202408(
                var_date = '2024-08-01T00:00:00.000Z',
                average_rent = 1496,
                median_rent = 1495,
                min_rent = 750,
                max_rent = 2800,
                average_rent_per_square_foot = 1.33,
                median_rent_per_square_foot = 1.27,
                min_rent_per_square_foot = 0.86,
                max_rent_per_square_foot = 2.52,
                average_square_footage = 1171,
                median_square_footage = 1100,
                min_square_footage = 650,
                max_square_footage = 2100,
                average_days_on_market = 66.49,
                median_days_on_market = 16,
                min_days_on_market = 1,
                max_days_on_market = 365,
                new_listings = 39,
                total_listings = 96,
                data_by_property_type = [
                    rentcast_client.models.market_statistics_200_response_rental_data_history_2024_08_data_by_property_type_inner.market_statistics_200_response_rentalData_history_2024_08_dataByPropertyType_inner(
                        property_type = 'Apartment', 
                        average_rent = 1118, 
                        median_rent = 1050, 
                        min_rent = 750, 
                        max_rent = 1975, 
                        average_rent_per_square_foot = 1.24, 
                        median_rent_per_square_foot = 1.07, 
                        min_rent_per_square_foot = 0.98, 
                        max_rent_per_square_foot = 2.16, 
                        average_square_footage = 922, 
                        median_square_footage = 950, 
                        min_square_footage = 650, 
                        max_square_footage = 1560, 
                        average_days_on_market = 63.82, 
                        median_days_on_market = 17, 
                        min_days_on_market = 1, 
                        max_days_on_market = 365, 
                        new_listings = 8, 
                        total_listings = 23, )
                    ],
                data_by_bedrooms = [
                    rentcast_client.models.market_statistics_200_response_rental_data_history_2024_08_data_by_bedrooms_inner.market_statistics_200_response_rentalData_history_2024_08_dataByBedrooms_inner(
                        bedrooms = 1, 
                        average_rent = 953, 
                        median_rent = 825, 
                        min_rent = 750, 
                        max_rent = 1610, 
                        average_rent_per_square_foot = 1.41, 
                        median_rent_per_square_foot = 1.3, 
                        min_rent_per_square_foot = 1.06, 
                        max_rent_per_square_foot = 2.16, 
                        average_square_footage = 732, 
                        median_square_footage = 675, 
                        min_square_footage = 650, 
                        max_square_footage = 950, 
                        average_days_on_market = 33.44, 
                        median_days_on_market = 17, 
                        min_days_on_market = 1, 
                        max_days_on_market = 124, 
                        new_listings = 3, 
                        total_listings = 10, )
                    ]
            )
        else:
            return RentcastMarketStatistics200ResponseRentalDataHistory202408(
        )
        """

    def testRentcastMarketStatistics200ResponseRentalDataHistory202408(self):
        """Test RentcastMarketStatistics200ResponseRentalDataHistory202408"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
