# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_value_estimate200_response import RentcastValueEstimate200Response

class TestRentcastValueEstimate200Response(unittest.TestCase):
    """RentcastValueEstimate200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastValueEstimate200Response:
        """Test RentcastValueEstimate200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastValueEstimate200Response`
        """
        model = RentcastValueEstimate200Response()
        if include_optional:
            return RentcastValueEstimate200Response(
                price = 221000,
                price_range_low = 208000,
                price_range_high = 233000,
                latitude = 29.475962,
                longitude = -98.351442,
                comparables = [
                    rentcast_client.models.value_estimate_200_response_comparables_inner.value_estimate_200_response_comparables_inner(
                        id = '5014-Fern-Lk,-San-Antonio,-TX-78244', 
                        formatted_address = '5014 Fern Lk, San Antonio, TX 78244', 
                        address_line1 = '5014 Fern Lk', 
                        address_line2 = null, 
                        city = 'San Antonio', 
                        state = 'TX', 
                        zip_code = '78244', 
                        county = 'Bexar', 
                        latitude = 29.471777, 
                        longitude = -98.350172, 
                        property_type = 'Single Family', 
                        bedrooms = 4, 
                        bathrooms = 2, 
                        square_footage = 1747, 
                        lot_size = 6316, 
                        year_built = 1986, 
                        price = 229900, 
                        listing_type = 'Standard', 
                        listed_date = '2024-04-03T00:00:00.000Z', 
                        removed_date = '2024-05-26T00:00:00.000Z', 
                        last_seen_date = '2024-05-25T13:11:55.018Z', 
                        days_on_market = 53, 
                        distance = 0.2994, 
                        days_old = 127, 
                        correlation = 0.9822, )
                    ]
            )
        else:
            return RentcastValueEstimate200Response(
        )
        """

    def testRentcastValueEstimate200Response(self):
        """Test RentcastValueEstimate200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
