# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_value_estimate200_response_subject_property import RentcastValueEstimate200ResponseSubjectProperty

class TestRentcastValueEstimate200ResponseSubjectProperty(unittest.TestCase):
    """RentcastValueEstimate200ResponseSubjectProperty unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastValueEstimate200ResponseSubjectProperty:
        """Test RentcastValueEstimate200ResponseSubjectProperty
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastValueEstimate200ResponseSubjectProperty`
        """
        model = RentcastValueEstimate200ResponseSubjectProperty()
        if include_optional:
            return RentcastValueEstimate200ResponseSubjectProperty(
                id = '5500-Grand-Lake-Dr,-San-Antonio,-TX-78244',
                formatted_address = '5500 Grand Lake Dr, San Antonio, TX 78244',
                address_line1 = '5500 Grand Lake Dr',
                address_line2 = '',
                city = 'San Antonio',
                state = 'TX',
                state_fips = '48',
                zip_code = '78244',
                county = 'Bexar',
                county_fips = '029',
                latitude = 29.476011,
                longitude = -98.351454,
                property_type = 'Single Family',
                bedrooms = 3,
                bathrooms = 2,
                square_footage = 1878,
                lot_size = 8843,
                year_built = 1973,
                last_sale_date = '2024-11-18T00:00:00.000Z',
                last_sale_price = 270000
            )
        else:
            return RentcastValueEstimate200ResponseSubjectProperty(
        )
        """

    def testRentcastValueEstimate200ResponseSubjectProperty(self):
        """Test RentcastValueEstimate200ResponseSubjectProperty"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
