# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history202409 import RentcastMarketStatistics200ResponseRentalDataHistory202409

class TestRentcastMarketStatistics200ResponseRentalDataHistory202409(unittest.TestCase):
    """RentcastMarketStatistics200ResponseRentalDataHistory202409 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastMarketStatistics200ResponseRentalDataHistory202409:
        """Test RentcastMarketStatistics200ResponseRentalDataHistory202409
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastMarketStatistics200ResponseRentalDataHistory202409`
        """
        model = RentcastMarketStatistics200ResponseRentalDataHistory202409()
        if include_optional:
            return RentcastMarketStatistics200ResponseRentalDataHistory202409(
                var_date = '2024-09-01T00:00:00.000Z',
                average_rent = 1536,
                median_rent = 1550,
                min_rent = 750,
                max_rent = 2800,
                average_rent_per_square_foot = 1.38,
                median_rent_per_square_foot = 1.33,
                min_rent_per_square_foot = 0.86,
                max_rent_per_square_foot = 2.52,
                average_square_footage = 1180,
                median_square_footage = 1120,
                min_square_footage = 590,
                max_square_footage = 2100,
                average_days_on_market = 32.03,
                median_days_on_market = 8,
                min_days_on_market = 1,
                max_days_on_market = 365,
                new_listings = 33,
                total_listings = 80,
                data_by_property_type = [
                    rentcast_client.models.market_statistics_200_response_rental_data_history_2024_09_data_by_property_type_inner.market_statistics_200_response_rentalData_history_2024_09_dataByPropertyType_inner(
                        property_type = 'Apartment', 
                        average_rent = 1148, 
                        median_rent = 975, 
                        min_rent = 750, 
                        max_rent = 1975, 
                        average_rent_per_square_foot = 1.25, 
                        median_rent_per_square_foot = 1.07, 
                        min_rent_per_square_foot = 1.03, 
                        max_rent_per_square_foot = 1.59, 
                        average_square_footage = 949, 
                        median_square_footage = 850, 
                        min_square_footage = 650, 
                        max_square_footage = 1560, 
                        average_days_on_market = 18.69, 
                        median_days_on_market = 17, 
                        min_days_on_market = 1, 
                        max_days_on_market = 80, 
                        new_listings = 7, 
                        total_listings = 14, )
                    ],
                data_by_bedrooms = [
                    rentcast_client.models.market_statistics_200_response_rental_data_history_2024_09_data_by_bedrooms_inner.market_statistics_200_response_rentalData_history_2024_09_dataByBedrooms_inner(
                        bedrooms = 1, 
                        average_rent = 899, 
                        median_rent = 850, 
                        min_rent = 750, 
                        max_rent = 1300, 
                        average_rent_per_square_foot = 1.35, 
                        median_rent_per_square_foot = 1.37, 
                        min_rent_per_square_foot = 1.06, 
                        max_rent_per_square_foot = 1.57, 
                        average_square_footage = 733, 
                        median_square_footage = 675, 
                        min_square_footage = 590, 
                        max_square_footage = 950, 
                        average_days_on_market = 27.86, 
                        median_days_on_market = 21, 
                        min_days_on_market = 1, 
                        max_days_on_market = 80, 
                        new_listings = 3, 
                        total_listings = 8, )
                    ]
            )
        else:
            return RentcastMarketStatistics200ResponseRentalDataHistory202409(
        )
        """

    def testRentcastMarketStatistics200ResponseRentalDataHistory202409(self):
        """Test RentcastMarketStatistics200ResponseRentalDataHistory202409"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
