# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_property_records200_response_inner_features import RentcastPropertyRecords200ResponseInnerFeatures

class TestRentcastPropertyRecords200ResponseInnerFeatures(unittest.TestCase):
    """RentcastPropertyRecords200ResponseInnerFeatures unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastPropertyRecords200ResponseInnerFeatures:
        """Test RentcastPropertyRecords200ResponseInnerFeatures
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastPropertyRecords200ResponseInnerFeatures`
        """
        model = RentcastPropertyRecords200ResponseInnerFeatures()
        if include_optional:
            return RentcastPropertyRecords200ResponseInnerFeatures(
                architecture_type = 'Contemporary',
                cooling = True,
                cooling_type = 'Central',
                exterior_type = 'Wood',
                fireplace = True,
                fireplace_type = 'Masonry',
                floor_count = 1,
                foundation_type = 'Slab / Mat / Raft',
                garage = True,
                garage_spaces = 2,
                garage_type = 'Garage',
                heating = True,
                heating_type = 'Forced Air',
                pool = True,
                pool_type = 'Concrete',
                roof_type = 'Asphalt',
                room_count = 5,
                unit_count = 1,
                view_type = 'City'
            )
        else:
            return RentcastPropertyRecords200ResponseInnerFeatures(
        )
        """

    def testRentcastPropertyRecords200ResponseInnerFeatures(self):
        """Test RentcastPropertyRecords200ResponseInnerFeatures"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
