# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from rentcast_client.models.rentcast_market_statistics200_response_sale_data_history202506 import RentcastMarketStatistics200ResponseSaleDataHistory202506
from rentcast_client.models.rentcast_market_statistics200_response_sale_data_history202507 import RentcastMarketStatistics200ResponseSaleDataHistory202507
from rentcast_client.models.rentcast_market_statistics200_response_sale_data_history202508 import RentcastMarketStatistics200ResponseSaleDataHistory202508
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class RentcastMarketStatistics200ResponseSaleDataHistory(BaseModel):
    """
    RentcastMarketStatistics200ResponseSaleDataHistory
    """ # noqa: E501
    var_2025_06: Optional[RentcastMarketStatistics200ResponseSaleDataHistory202506] = Field(default=None, alias="2025-06")
    var_2025_07: Optional[RentcastMarketStatistics200ResponseSaleDataHistory202507] = Field(default=None, alias="2025-07")
    var_2025_08: Optional[RentcastMarketStatistics200ResponseSaleDataHistory202508] = Field(default=None, alias="2025-08")
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["2025-06", "2025-07", "2025-08"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RentcastMarketStatistics200ResponseSaleDataHistory from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of var_2025_06
        if self.var_2025_06:
            _dict['2025-06'] = self.var_2025_06.to_dict()
        # override the default output from pydantic by calling `to_dict()` of var_2025_07
        if self.var_2025_07:
            _dict['2025-07'] = self.var_2025_07.to_dict()
        # override the default output from pydantic by calling `to_dict()` of var_2025_08
        if self.var_2025_08:
            _dict['2025-08'] = self.var_2025_08.to_dict()
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RentcastMarketStatistics200ResponseSaleDataHistory from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "2025-06": RentcastMarketStatistics200ResponseSaleDataHistory202506.from_dict(obj["2025-06"]) if obj.get("2025-06") is not None else None,
            "2025-07": RentcastMarketStatistics200ResponseSaleDataHistory202507.from_dict(obj["2025-07"]) if obj.get("2025-07") is not None else None,
            "2025-08": RentcastMarketStatistics200ResponseSaleDataHistory202508.from_dict(obj["2025-08"]) if obj.get("2025-08") is not None else None
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj


