# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_sale_listings200_response_inner import RentcastSaleListings200ResponseInner

class TestRentcastSaleListings200ResponseInner(unittest.TestCase):
    """RentcastSaleListings200ResponseInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastSaleListings200ResponseInner:
        """Test RentcastSaleListings200ResponseInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastSaleListings200ResponseInner`
        """
        model = RentcastSaleListings200ResponseInner()
        if include_optional:
            return RentcastSaleListings200ResponseInner(
                id = '3821-Hargis-St,-Austin,-TX-78723',
                formatted_address = '3821 Hargis St, Austin, TX 78723',
                address_line1 = '3821 Hargis St',
                address_line2 = None,
                city = 'Austin',
                state = 'TX',
                zip_code = '78723',
                county = 'Travis',
                latitude = 30.290643,
                longitude = -97.701547,
                property_type = 'Single Family',
                bedrooms = 4,
                bathrooms = 2.5,
                square_footage = 2345,
                lot_size = 3284,
                year_built = 2008,
                hoa = rentcast_client.models.sale_listings_200_response_inner_hoa.sale_listings_200_response_inner_hoa(
                    fee = 65, ),
                status = 'Active',
                price = 899000,
                listing_type = 'Standard',
                listed_date = '2024-06-24T00:00:00.000Z',
                removed_date = None,
                created_date = '2021-06-25T00:00:00.000Z',
                last_seen_date = '2024-09-30T13:11:47.157Z',
                days_on_market = 99,
                mls_name = 'UnlockMLS',
                mls_number = '5519228',
                listing_agent = rentcast_client.models.sale_listings_200_response_inner_listing_agent.sale_listings_200_response_inner_listingAgent(
                    name = 'Jennifer Welch', 
                    phone = '5124313110', 
                    email = 'jennifer@gottesmanresidential.com', 
                    website = 'https://www.gottesmanresidential.com', ),
                listing_office = rentcast_client.models.sale_listings_200_response_inner_listing_office.sale_listings_200_response_inner_listingOffice(
                    name = 'Gottesman Residential R.E.', 
                    phone = '5124512422', 
                    email = 'nataliem@gottesmanresidential.com', 
                    website = 'https://www.gottesmanresidential.com', ),
                history = rentcast_client.models.sale_listings_200_response_inner_history.sale_listings_200_response_inner_history(
                    2024_06_24 = rentcast_client.models.sale_listings_200_response_inner_history_2024_06_24.sale_listings_200_response_inner_history_2024_06_24(
                        event = 'Sale Listing', 
                        price = 899000, 
                        listing_type = 'Standard', 
                        listed_date = '2024-06-24T00:00:00.000Z', 
                        removed_date = null, 
                        days_on_market = 99, ), )
            )
        else:
            return RentcastSaleListings200ResponseInner(
        )
        """

    def testRentcastSaleListings200ResponseInner(self):
        """Test RentcastSaleListings200ResponseInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
