# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_market_statistics200_response import RentcastMarketStatistics200Response

class TestRentcastMarketStatistics200Response(unittest.TestCase):
    """RentcastMarketStatistics200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastMarketStatistics200Response:
        """Test RentcastMarketStatistics200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastMarketStatistics200Response`
        """
        model = RentcastMarketStatistics200Response()
        if include_optional:
            return RentcastMarketStatistics200Response(
                id = '29611',
                zip_code = '29611',
                sale_data = rentcast_client.models.market_statistics_200_response_sale_data.market_statistics_200_response_saleData(
                    last_updated_date = '2024-10-14T00:00:00.000Z', 
                    average_price = 291933, 
                    median_price = 276990, 
                    min_price = 20000, 
                    max_price = 1500000, 
                    average_price_per_square_foot = 186.53, 
                    median_price_per_square_foot = 178, 
                    min_price_per_square_foot = 64.9, 
                    max_price_per_square_foot = 500, 
                    average_square_footage = 1698, 
                    median_square_footage = 1600, 
                    min_square_footage = 610, 
                    max_square_footage = 4588, 
                    average_days_on_market = 67.21, 
                    median_days_on_market = 45, 
                    min_days_on_market = 2, 
                    max_days_on_market = 348, 
                    new_listings = 21, 
                    total_listings = 265, 
                    data_by_property_type = [
                        rentcast_client.models.market_statistics_200_response_sale_data_data_by_property_type_inner.market_statistics_200_response_saleData_dataByPropertyType_inner(
                            property_type = 'Condo', 
                            average_price = 144900, 
                            median_price = 144900, 
                            min_price = 144900, 
                            max_price = 144900, 
                            average_price_per_square_foot = 129.26, 
                            median_price_per_square_foot = 129.26, 
                            min_price_per_square_foot = 129.26, 
                            max_price_per_square_foot = 129.26, 
                            average_square_footage = 1121, 
                            median_square_footage = 1121, 
                            min_square_footage = 1121, 
                            max_square_footage = 1121, 
                            average_days_on_market = 61, 
                            median_days_on_market = 61, 
                            min_days_on_market = 61, 
                            max_days_on_market = 61, 
                            new_listings = 0, 
                            total_listings = 1, )
                        ], 
                    data_by_bedrooms = [
                        rentcast_client.models.market_statistics_200_response_sale_data_data_by_bedrooms_inner.market_statistics_200_response_saleData_dataByBedrooms_inner(
                            bedrooms = 1, 
                            average_price = 186725, 
                            median_price = 153000, 
                            min_price = 147900, 
                            max_price = 237000, 
                            average_price_per_square_foot = 240.84, 
                            median_price_per_square_foot = 191.01, 
                            min_price_per_square_foot = 184.88, 
                            max_price_per_square_foot = 342.62, 
                            average_square_footage = 795, 
                            median_square_footage = 800, 
                            min_square_footage = 610, 
                            max_square_footage = 968, 
                            average_days_on_market = 123, 
                            median_days_on_market = 56, 
                            min_days_on_market = 20, 
                            max_days_on_market = 314, 
                            new_listings = 0, 
                            total_listings = 4, )
                        ], 
                    history = rentcast_client.models.market_statistics_200_response_sale_data_history.market_statistics_200_response_saleData_history(
                        2024_08 = rentcast_client.models.market_statistics_200_response_sale_data_history_2024_08.market_statistics_200_response_saleData_history_2024_08(
                            date = '2024-08-01T00:00:00.000Z', 
                            average_price = 304256, 
                            median_price = 284900, 
                            min_price = 75000, 
                            max_price = 975000, 
                            average_price_per_square_foot = 177.79, 
                            median_price_per_square_foot = 174.82, 
                            min_price_per_square_foot = 115.81, 
                            max_price_per_square_foot = 342.62, 
                            average_square_footage = 1759, 
                            median_square_footage = 1591, 
                            min_square_footage = 610, 
                            max_square_footage = 4588, 
                            average_days_on_market = 56.94, 
                            median_days_on_market = 41, 
                            min_days_on_market = 2, 
                            max_days_on_market = 327, 
                            new_listings = 56, 
                            total_listings = 215, ), 
                        2024_09 = rentcast_client.models.market_statistics_200_response_sale_data_history_2024_09.market_statistics_200_response_saleData_history_2024_09(
                            date = '2024-09-01T00:00:00.000Z', 
                            average_price = 291174, 
                            median_price = 277990, 
                            min_price = 20000, 
                            max_price = 1500000, 
                            average_price_per_square_foot = 187.39, 
                            median_price_per_square_foot = 178, 
                            min_price_per_square_foot = 64.9, 
                            max_price_per_square_foot = 500, 
                            average_square_footage = 1695, 
                            median_square_footage = 1600, 
                            min_square_footage = 610, 
                            max_square_footage = 4588, 
                            average_days_on_market = 63.65, 
                            median_days_on_market = 41, 
                            min_days_on_market = 2, 
                            max_days_on_market = 357, 
                            new_listings = 66, 
                            total_listings = 269, ), 
                        2024_10 = rentcast_client.models.market_statistics_200_response_sale_data_history_2024_10.market_statistics_200_response_saleData_history_2024_10(
                            date = '2024-10-01T00:00:00.000Z', 
                            average_price = 291933, 
                            median_price = 276990, 
                            min_price = 20000, 
                            max_price = 1500000, 
                            average_price_per_square_foot = 186.53, 
                            median_price_per_square_foot = 178, 
                            min_price_per_square_foot = 64.9, 
                            max_price_per_square_foot = 500, 
                            average_square_footage = 1698, 
                            median_square_footage = 1600, 
                            min_square_footage = 610, 
                            max_square_footage = 4588, 
                            average_days_on_market = 67.21, 
                            median_days_on_market = 45, 
                            min_days_on_market = 2, 
                            max_days_on_market = 348, 
                            new_listings = 21, 
                            total_listings = 265, ), ), ),
                rental_data = rentcast_client.models.market_statistics_200_response_rental_data.market_statistics_200_response_rentalData(
                    last_updated_date = '2024-10-14T00:00:00.000Z', 
                    average_rent = 1521, 
                    median_rent = 1495, 
                    min_rent = 750, 
                    max_rent = 2700, 
                    average_rent_per_square_foot = 1.38, 
                    median_rent_per_square_foot = 1.3, 
                    min_rent_per_square_foot = 0.86, 
                    max_rent_per_square_foot = 2.59, 
                    average_square_footage = 1175, 
                    median_square_footage = 1100, 
                    min_square_footage = 590, 
                    max_square_footage = 2100, 
                    average_days_on_market = 25, 
                    median_days_on_market = 8, 
                    min_days_on_market = 1, 
                    max_days_on_market = 304, 
                    new_listings = 18, 
                    total_listings = 76, 
                    data_by_property_type = [
                        rentcast_client.models.market_statistics_200_response_rental_data_data_by_property_type_inner.market_statistics_200_response_rentalData_dataByPropertyType_inner(
                            property_type = 'Apartment', 
                            average_rent = 1148, 
                            median_rent = 1050, 
                            min_rent = 750, 
                            max_rent = 1975, 
                            average_rent_per_square_foot = 1.23, 
                            median_rent_per_square_foot = 1.13, 
                            min_rent_per_square_foot = 1.03, 
                            max_rent_per_square_foot = 1.59, 
                            average_square_footage = 957, 
                            median_square_footage = 950, 
                            min_square_footage = 650, 
                            max_square_footage = 1560, 
                            average_days_on_market = 17.43, 
                            median_days_on_market = 1, 
                            min_days_on_market = 1, 
                            max_days_on_market = 80, 
                            new_listings = 5, 
                            total_listings = 15, )
                        ], 
                    data_by_bedrooms = [
                        rentcast_client.models.market_statistics_200_response_rental_data_data_by_bedrooms_inner.market_statistics_200_response_rentalData_dataByBedrooms_inner(
                            bedrooms = 1, 
                            average_rent = 842, 
                            median_rent = 850, 
                            min_rent = 750, 
                            max_rent = 945, 
                            average_rent_per_square_foot = 1.35, 
                            median_rent_per_square_foot = 1.3, 
                            min_rent_per_square_foot = 1.06, 
                            max_rent_per_square_foot = 1.57, 
                            average_square_footage = 679, 
                            median_square_footage = 650, 
                            min_square_footage = 590, 
                            max_square_footage = 800, 
                            average_days_on_market = 27.33, 
                            median_days_on_market = 9, 
                            min_days_on_market = 1, 
                            max_days_on_market = 80, 
                            new_listings = 1, 
                            total_listings = 7, )
                        ], 
                    history = rentcast_client.models.market_statistics_200_response_rental_data_history.market_statistics_200_response_rentalData_history(
                        2024_08 = rentcast_client.models.market_statistics_200_response_rental_data_history_2024_08.market_statistics_200_response_rentalData_history_2024_08(
                            date = '2024-08-01T00:00:00.000Z', 
                            average_rent = 1496, 
                            median_rent = 1495, 
                            min_rent = 750, 
                            max_rent = 2800, 
                            average_rent_per_square_foot = 1.33, 
                            median_rent_per_square_foot = 1.27, 
                            min_rent_per_square_foot = 0.86, 
                            max_rent_per_square_foot = 2.52, 
                            average_square_footage = 1171, 
                            median_square_footage = 1100, 
                            min_square_footage = 650, 
                            max_square_footage = 2100, 
                            average_days_on_market = 66.49, 
                            median_days_on_market = 16, 
                            min_days_on_market = 1, 
                            max_days_on_market = 365, 
                            new_listings = 39, 
                            total_listings = 96, ), 
                        2024_09 = rentcast_client.models.market_statistics_200_response_rental_data_history_2024_09.market_statistics_200_response_rentalData_history_2024_09(
                            date = '2024-09-01T00:00:00.000Z', 
                            average_rent = 1536, 
                            median_rent = 1550, 
                            min_rent = 750, 
                            max_rent = 2800, 
                            average_rent_per_square_foot = 1.38, 
                            median_rent_per_square_foot = 1.33, 
                            min_rent_per_square_foot = 0.86, 
                            max_rent_per_square_foot = 2.52, 
                            average_square_footage = 1180, 
                            median_square_footage = 1120, 
                            min_square_footage = 590, 
                            max_square_footage = 2100, 
                            average_days_on_market = 32.03, 
                            median_days_on_market = 8, 
                            min_days_on_market = 1, 
                            max_days_on_market = 365, 
                            new_listings = 33, 
                            total_listings = 80, ), 
                        2024_10 = rentcast_client.models.market_statistics_200_response_rental_data_history_2024_10.market_statistics_200_response_rentalData_history_2024_10(
                            date = '2024-10-01T00:00:00.000Z', 
                            average_rent = 1521, 
                            median_rent = 1495, 
                            min_rent = 750, 
                            max_rent = 2700, 
                            average_rent_per_square_foot = 1.38, 
                            median_rent_per_square_foot = 1.3, 
                            min_rent_per_square_foot = 0.86, 
                            max_rent_per_square_foot = 2.59, 
                            average_square_footage = 1175, 
                            median_square_footage = 1100, 
                            min_square_footage = 590, 
                            max_square_footage = 2100, 
                            average_days_on_market = 25, 
                            median_days_on_market = 8, 
                            min_days_on_market = 1, 
                            max_days_on_market = 304, 
                            new_listings = 18, 
                            total_listings = 76, ), ), )
            )
        else:
            return RentcastMarketStatistics200Response(
        )
        """

    def testRentcastMarketStatistics200Response(self):
        """Test RentcastMarketStatistics200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
