# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_value_estimate401_response import RentcastValueEstimate401Response

class TestRentcastValueEstimate401Response(unittest.TestCase):
    """RentcastValueEstimate401Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastValueEstimate401Response:
        """Test RentcastValueEstimate401Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastValueEstimate401Response`
        """
        model = RentcastValueEstimate401Response()
        if include_optional:
            return RentcastValueEstimate401Response(
                status = 401,
                error = 'auth/api-key-invalid',
                message = 'No API key provided in request. An API key must be provided in the 'X-Api-Key' header'
            )
        else:
            return RentcastValueEstimate401Response(
        )
        """

    def testRentcastValueEstimate401Response(self):
        """Test RentcastValueEstimate401Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
