# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_market_statistics200_response_sale_data import RentcastMarketStatistics200ResponseSaleData

class TestRentcastMarketStatistics200ResponseSaleData(unittest.TestCase):
    """RentcastMarketStatistics200ResponseSaleData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastMarketStatistics200ResponseSaleData:
        """Test RentcastMarketStatistics200ResponseSaleData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastMarketStatistics200ResponseSaleData`
        """
        model = RentcastMarketStatistics200ResponseSaleData()
        if include_optional:
            return RentcastMarketStatistics200ResponseSaleData(
                last_updated_date = '2024-10-14T00:00:00.000Z',
                average_price = 291933,
                median_price = 276990,
                min_price = 20000,
                max_price = 1500000,
                average_price_per_square_foot = 186.53,
                median_price_per_square_foot = 178,
                min_price_per_square_foot = 64.9,
                max_price_per_square_foot = 500,
                average_square_footage = 1698,
                median_square_footage = 1600,
                min_square_footage = 610,
                max_square_footage = 4588,
                average_days_on_market = 67.21,
                median_days_on_market = 45,
                min_days_on_market = 2,
                max_days_on_market = 348,
                new_listings = 21,
                total_listings = 265,
                data_by_property_type = [
                    rentcast_client.models.market_statistics_200_response_sale_data_data_by_property_type_inner.market_statistics_200_response_saleData_dataByPropertyType_inner(
                        property_type = 'Condo', 
                        average_price = 144900, 
                        median_price = 144900, 
                        min_price = 144900, 
                        max_price = 144900, 
                        average_price_per_square_foot = 129.26, 
                        median_price_per_square_foot = 129.26, 
                        min_price_per_square_foot = 129.26, 
                        max_price_per_square_foot = 129.26, 
                        average_square_footage = 1121, 
                        median_square_footage = 1121, 
                        min_square_footage = 1121, 
                        max_square_footage = 1121, 
                        average_days_on_market = 61, 
                        median_days_on_market = 61, 
                        min_days_on_market = 61, 
                        max_days_on_market = 61, 
                        new_listings = 0, 
                        total_listings = 1, )
                    ],
                data_by_bedrooms = [
                    rentcast_client.models.market_statistics_200_response_sale_data_data_by_bedrooms_inner.market_statistics_200_response_saleData_dataByBedrooms_inner(
                        bedrooms = 1, 
                        average_price = 186725, 
                        median_price = 153000, 
                        min_price = 147900, 
                        max_price = 237000, 
                        average_price_per_square_foot = 240.84, 
                        median_price_per_square_foot = 191.01, 
                        min_price_per_square_foot = 184.88, 
                        max_price_per_square_foot = 342.62, 
                        average_square_footage = 795, 
                        median_square_footage = 800, 
                        min_square_footage = 610, 
                        max_square_footage = 968, 
                        average_days_on_market = 123, 
                        median_days_on_market = 56, 
                        min_days_on_market = 20, 
                        max_days_on_market = 314, 
                        new_listings = 0, 
                        total_listings = 4, )
                    ],
                history = rentcast_client.models.market_statistics_200_response_sale_data_history.market_statistics_200_response_saleData_history(
                    2024_08 = rentcast_client.models.market_statistics_200_response_sale_data_history_2024_08.market_statistics_200_response_saleData_history_2024_08(
                        date = '2024-08-01T00:00:00.000Z', 
                        average_price = 304256, 
                        median_price = 284900, 
                        min_price = 75000, 
                        max_price = 975000, 
                        average_price_per_square_foot = 177.79, 
                        median_price_per_square_foot = 174.82, 
                        min_price_per_square_foot = 115.81, 
                        max_price_per_square_foot = 342.62, 
                        average_square_footage = 1759, 
                        median_square_footage = 1591, 
                        min_square_footage = 610, 
                        max_square_footage = 4588, 
                        average_days_on_market = 56.94, 
                        median_days_on_market = 41, 
                        min_days_on_market = 2, 
                        max_days_on_market = 327, 
                        new_listings = 56, 
                        total_listings = 215, 
                        data_by_property_type = [
                            rentcast_client.models.market_statistics_200_response_sale_data_history_2024_08_data_by_property_type_inner.market_statistics_200_response_saleData_history_2024_08_dataByPropertyType_inner(
                                property_type = 'Condo', 
                                average_price = 175445, 
                                median_price = 154500, 
                                min_price = 154500, 
                                max_price = 196390, 
                                average_price_per_square_foot = null, 
                                median_price_per_square_foot = null, 
                                min_price_per_square_foot = null, 
                                max_price_per_square_foot = null, 
                                average_square_footage = null, 
                                median_square_footage = null, 
                                min_square_footage = null, 
                                max_square_footage = null, 
                                average_days_on_market = 124, 
                                median_days_on_market = 18, 
                                min_days_on_market = 18, 
                                max_days_on_market = 230, 
                                new_listings = 1, 
                                total_listings = 2, )
                            ], 
                        data_by_bedrooms = [
                            rentcast_client.models.market_statistics_200_response_sale_data_history_2024_08_data_by_bedrooms_inner.market_statistics_200_response_saleData_history_2024_08_dataByBedrooms_inner(
                                bedrooms = 1, 
                                average_price = 197967, 
                                median_price = 209000, 
                                min_price = 147900, 
                                max_price = 237000, 
                                average_price_per_square_foot = 342.62, 
                                median_price_per_square_foot = 342.62, 
                                min_price_per_square_foot = 342.62, 
                                max_price_per_square_foot = 342.62, 
                                average_square_footage = 610, 
                                median_square_footage = 610, 
                                min_square_footage = 610, 
                                max_square_footage = 610, 
                                average_days_on_market = 132, 
                                median_days_on_market = 69, 
                                min_days_on_market = 56, 
                                max_days_on_market = 271, 
                                new_listings = 0, 
                                total_listings = 3, )
                            ], ), 
                    2024_09 = rentcast_client.models.market_statistics_200_response_sale_data_history_2024_09.market_statistics_200_response_saleData_history_2024_09(
                        date = '2024-09-01T00:00:00.000Z', 
                        average_price = 291174, 
                        median_price = 277990, 
                        min_price = 20000, 
                        max_price = 1500000, 
                        average_price_per_square_foot = 187.39, 
                        median_price_per_square_foot = 178, 
                        min_price_per_square_foot = 64.9, 
                        max_price_per_square_foot = 500, 
                        average_square_footage = 1695, 
                        median_square_footage = 1600, 
                        min_square_footage = 610, 
                        max_square_footage = 4588, 
                        average_days_on_market = 63.65, 
                        median_days_on_market = 41, 
                        min_days_on_market = 2, 
                        max_days_on_market = 357, 
                        new_listings = 66, 
                        total_listings = 269, ), 
                    2024_10 = rentcast_client.models.market_statistics_200_response_sale_data_history_2024_10.market_statistics_200_response_saleData_history_2024_10(
                        date = '2024-10-01T00:00:00.000Z', 
                        average_price = 291933, 
                        median_price = 276990, 
                        min_price = 20000, 
                        max_price = 1500000, 
                        average_price_per_square_foot = 186.53, 
                        median_price_per_square_foot = 178, 
                        min_price_per_square_foot = 64.9, 
                        max_price_per_square_foot = 500, 
                        average_square_footage = 1698, 
                        median_square_footage = 1600, 
                        min_square_footage = 610, 
                        max_square_footage = 4588, 
                        average_days_on_market = 67.21, 
                        median_days_on_market = 45, 
                        min_days_on_market = 2, 
                        max_days_on_market = 348, 
                        new_listings = 21, 
                        total_listings = 265, ), )
            )
        else:
            return RentcastMarketStatistics200ResponseSaleData(
        )
        """

    def testRentcastMarketStatistics200ResponseSaleData(self):
        """Test RentcastMarketStatistics200ResponseSaleData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
