# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history202506_data_by_bedrooms_inner import RentcastMarketStatistics200ResponseRentalDataHistory202506DataByBedroomsInner

class TestRentcastMarketStatistics200ResponseRentalDataHistory202506DataByBedroomsInner(unittest.TestCase):
    """RentcastMarketStatistics200ResponseRentalDataHistory202506DataByBedroomsInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastMarketStatistics200ResponseRentalDataHistory202506DataByBedroomsInner:
        """Test RentcastMarketStatistics200ResponseRentalDataHistory202506DataByBedroomsInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastMarketStatistics200ResponseRentalDataHistory202506DataByBedroomsInner`
        """
        model = RentcastMarketStatistics200ResponseRentalDataHistory202506DataByBedroomsInner()
        if include_optional:
            return RentcastMarketStatistics200ResponseRentalDataHistory202506DataByBedroomsInner(
                bedrooms = 1,
                average_rent = 852,
                median_rent = 930,
                min_rent = 400,
                max_rent = 1100,
                average_rent_per_square_foot = 1.35,
                median_rent_per_square_foot = 1.34,
                min_rent_per_square_foot = 1,
                max_rent_per_square_foot = 1.6,
                average_square_footage = 673,
                median_square_footage = 650,
                min_square_footage = 590,
                max_square_footage = 800,
                average_days_on_market = 47.4,
                median_days_on_market = 1,
                min_days_on_market = 1,
                max_days_on_market = 257,
                new_listings = 5,
                total_listings = 11
            )
        else:
            return RentcastMarketStatistics200ResponseRentalDataHistory202506DataByBedroomsInner(
        )
        """

    def testRentcastMarketStatistics200ResponseRentalDataHistory202506DataByBedroomsInner(self):
        """Test RentcastMarketStatistics200ResponseRentalDataHistory202506DataByBedroomsInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
