# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_rent_estimate_long_term200_response import RentcastRentEstimateLongTerm200Response

class TestRentcastRentEstimateLongTerm200Response(unittest.TestCase):
    """RentcastRentEstimateLongTerm200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastRentEstimateLongTerm200Response:
        """Test RentcastRentEstimateLongTerm200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastRentEstimateLongTerm200Response`
        """
        model = RentcastRentEstimateLongTerm200Response()
        if include_optional:
            return RentcastRentEstimateLongTerm200Response(
                rent = 1670,
                rent_range_low = 1630,
                rent_range_high = 1710,
                latitude = 29.475962,
                longitude = -98.351442,
                comparables = [
                    rentcast_client.models.rent_estimate_long_term_200_response_comparables_inner.rent_estimate_long_term_200_response_comparables_inner(
                        id = '5711-Leon-Pl,-San-Antonio,-TX-78244', 
                        formatted_address = '5711 Leon Pl, San Antonio, TX 78244', 
                        address_line1 = '5711 Leon Pl', 
                        address_line2 = null, 
                        city = 'San Antonio', 
                        state = 'TX', 
                        zip_code = '78244', 
                        county = 'Bexar', 
                        latitude = 29.481808, 
                        longitude = -98.346176, 
                        property_type = 'Single Family', 
                        bedrooms = 4, 
                        bathrooms = 2, 
                        square_footage = 1627, 
                        lot_size = 4617, 
                        year_built = 2021, 
                        price = 1690, 
                        listing_type = 'Standard', 
                        listed_date = '2024-03-15T00:00:00.000Z', 
                        removed_date = '2024-07-04T00:00:00.000Z', 
                        last_seen_date = '2024-07-03T04:26:03.433Z', 
                        days_on_market = 111, 
                        distance = 0.5139, 
                        days_old = 88, 
                        correlation = 0.9879, )
                    ]
            )
        else:
            return RentcastRentEstimateLongTerm200Response(
        )
        """

    def testRentcastRentEstimateLongTerm200Response(self):
        """Test RentcastRentEstimateLongTerm200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
