# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_value_estimate200_response_comparables_inner import RentcastValueEstimate200ResponseComparablesInner

class TestRentcastValueEstimate200ResponseComparablesInner(unittest.TestCase):
    """RentcastValueEstimate200ResponseComparablesInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastValueEstimate200ResponseComparablesInner:
        """Test RentcastValueEstimate200ResponseComparablesInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastValueEstimate200ResponseComparablesInner`
        """
        model = RentcastValueEstimate200ResponseComparablesInner()
        if include_optional:
            return RentcastValueEstimate200ResponseComparablesInner(
                id = '5014-Fern-Lk,-San-Antonio,-TX-78244',
                formatted_address = '5014 Fern Lk, San Antonio, TX 78244',
                address_line1 = '5014 Fern Lk',
                address_line2 = None,
                city = 'San Antonio',
                state = 'TX',
                zip_code = '78244',
                county = 'Bexar',
                latitude = 29.471777,
                longitude = -98.350172,
                property_type = 'Single Family',
                bedrooms = 4,
                bathrooms = 2,
                square_footage = 1747,
                lot_size = 6316,
                year_built = 1986,
                price = 229900,
                listing_type = 'Standard',
                listed_date = '2024-04-03T00:00:00.000Z',
                removed_date = '2024-05-26T00:00:00.000Z',
                last_seen_date = '2024-05-25T13:11:55.018Z',
                days_on_market = 53,
                distance = 0.2994,
                days_old = 127,
                correlation = 0.9822
            )
        else:
            return RentcastValueEstimate200ResponseComparablesInner(
        )
        """

    def testRentcastValueEstimate200ResponseComparablesInner(self):
        """Test RentcastValueEstimate200ResponseComparablesInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
