# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history202410 import RentcastMarketStatistics200ResponseRentalDataHistory202410

class TestRentcastMarketStatistics200ResponseRentalDataHistory202410(unittest.TestCase):
    """RentcastMarketStatistics200ResponseRentalDataHistory202410 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastMarketStatistics200ResponseRentalDataHistory202410:
        """Test RentcastMarketStatistics200ResponseRentalDataHistory202410
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastMarketStatistics200ResponseRentalDataHistory202410`
        """
        model = RentcastMarketStatistics200ResponseRentalDataHistory202410()
        if include_optional:
            return RentcastMarketStatistics200ResponseRentalDataHistory202410(
                var_date = '2024-10-01T00:00:00.000Z',
                average_rent = 1521,
                median_rent = 1495,
                min_rent = 750,
                max_rent = 2700,
                average_rent_per_square_foot = 1.38,
                median_rent_per_square_foot = 1.3,
                min_rent_per_square_foot = 0.86,
                max_rent_per_square_foot = 2.59,
                average_square_footage = 1175,
                median_square_footage = 1100,
                min_square_footage = 590,
                max_square_footage = 2100,
                average_days_on_market = 25,
                median_days_on_market = 8,
                min_days_on_market = 1,
                max_days_on_market = 304,
                new_listings = 18,
                total_listings = 76,
                data_by_property_type = [
                    rentcast_client.models.market_statistics_200_response_rental_data_data_by_property_type_inner.market_statistics_200_response_rentalData_dataByPropertyType_inner(
                        property_type = 'Apartment', 
                        average_rent = 1148, 
                        median_rent = 1050, 
                        min_rent = 750, 
                        max_rent = 1975, 
                        average_rent_per_square_foot = 1.23, 
                        median_rent_per_square_foot = 1.13, 
                        min_rent_per_square_foot = 1.03, 
                        max_rent_per_square_foot = 1.59, 
                        average_square_footage = 957, 
                        median_square_footage = 950, 
                        min_square_footage = 650, 
                        max_square_footage = 1560, 
                        average_days_on_market = 17.43, 
                        median_days_on_market = 1, 
                        min_days_on_market = 1, 
                        max_days_on_market = 80, 
                        new_listings = 5, 
                        total_listings = 15, )
                    ],
                data_by_bedrooms = [
                    rentcast_client.models.market_statistics_200_response_rental_data_data_by_bedrooms_inner.market_statistics_200_response_rentalData_dataByBedrooms_inner(
                        bedrooms = 1, 
                        average_rent = 842, 
                        median_rent = 850, 
                        min_rent = 750, 
                        max_rent = 945, 
                        average_rent_per_square_foot = 1.35, 
                        median_rent_per_square_foot = 1.3, 
                        min_rent_per_square_foot = 1.06, 
                        max_rent_per_square_foot = 1.57, 
                        average_square_footage = 679, 
                        median_square_footage = 650, 
                        min_square_footage = 590, 
                        max_square_footage = 800, 
                        average_days_on_market = 27.33, 
                        median_days_on_market = 9, 
                        min_days_on_market = 1, 
                        max_days_on_market = 80, 
                        new_listings = 1, 
                        total_listings = 7, )
                    ]
            )
        else:
            return RentcastMarketStatistics200ResponseRentalDataHistory202410(
        )
        """

    def testRentcastMarketStatistics200ResponseRentalDataHistory202410(self):
        """Test RentcastMarketStatistics200ResponseRentalDataHistory202410"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
