# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_rental_listings_long_term200_response_inner import RentcastRentalListingsLongTerm200ResponseInner

class TestRentcastRentalListingsLongTerm200ResponseInner(unittest.TestCase):
    """RentcastRentalListingsLongTerm200ResponseInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastRentalListingsLongTerm200ResponseInner:
        """Test RentcastRentalListingsLongTerm200ResponseInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastRentalListingsLongTerm200ResponseInner`
        """
        model = RentcastRentalListingsLongTerm200ResponseInner()
        if include_optional:
            return RentcastRentalListingsLongTerm200ResponseInner(
                id = '2005-Arborside-Dr,-Austin,-TX-78754',
                formatted_address = '2005 Arborside Dr, Austin, TX 78754',
                address_line1 = '2005 Arborside Dr',
                address_line2 = None,
                city = 'Austin',
                state = 'TX',
                zip_code = '78754',
                county = 'Travis',
                latitude = 30.35837,
                longitude = -97.66508,
                property_type = 'Single Family',
                bedrooms = 3,
                bathrooms = 2.5,
                square_footage = 1681,
                lot_size = 4360,
                year_built = 2019,
                hoa = rentcast_client.models.rental_listings_long_term_200_response_inner_hoa.rental_listings_long_term_200_response_inner_hoa(
                    fee = 45, ),
                status = 'Active',
                price = 2200,
                listing_type = 'Standard',
                listed_date = '2024-09-18T00:00:00.000Z',
                removed_date = None,
                created_date = '2024-09-19T00:00:00.000Z',
                last_seen_date = '2024-09-30T03:49:20.620Z',
                days_on_market = 13,
                mls_name = 'CentralTexas',
                mls_number = '556965',
                listing_agent = rentcast_client.models.rental_listings_long_term_200_response_inner_listing_agent.rental_listings_long_term_200_response_inner_listingAgent(
                    name = 'Zachary Barton', 
                    phone = '5129948203', 
                    email = 'zak-barton@realtytexas.com', 
                    website = 'https://zak-barton.realtytexas.homes', ),
                listing_office = rentcast_client.models.rental_listings_long_term_200_response_inner_listing_office.rental_listings_long_term_200_response_inner_listingOffice(
                    name = 'Realty Texas', 
                    phone = '5124765348', 
                    email = 'sales@realtytexas.com', 
                    website = 'https://www.realtytexas.com', ),
                history = rentcast_client.models.rental_listings_long_term_200_response_inner_history.rental_listings_long_term_200_response_inner_history(
                    2024_09_18 = rentcast_client.models.rental_listings_long_term_200_response_inner_history_2024_09_18.rental_listings_long_term_200_response_inner_history_2024_09_18(
                        event = 'Rental Listing', 
                        price = 2200, 
                        listing_type = 'Standard', 
                        listed_date = '2024-09-18T00:00:00.000Z', 
                        removed_date = null, 
                        days_on_market = 13, ), )
            )
        else:
            return RentcastRentalListingsLongTerm200ResponseInner(
        )
        """

    def testRentcastRentalListingsLongTerm200ResponseInner(self):
        """Test RentcastRentalListingsLongTerm200ResponseInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
