# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_property_records200_response_inner import RentcastPropertyRecords200ResponseInner

class TestRentcastPropertyRecords200ResponseInner(unittest.TestCase):
    """RentcastPropertyRecords200ResponseInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastPropertyRecords200ResponseInner:
        """Test RentcastPropertyRecords200ResponseInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastPropertyRecords200ResponseInner`
        """
        model = RentcastPropertyRecords200ResponseInner()
        if include_optional:
            return RentcastPropertyRecords200ResponseInner(
                id = '5500-Grand-Lake-Dr,-San-Antonio,-TX-78244',
                formatted_address = '5500 Grand Lake Dr, San Antonio, TX 78244',
                address_line1 = '5500 Grand Lake Dr',
                address_line2 = None,
                city = 'San Antonio',
                state = 'TX',
                zip_code = '78244',
                county = 'Bexar',
                latitude = 29.476011,
                longitude = -98.351454,
                property_type = 'Single Family',
                bedrooms = 3,
                bathrooms = 2,
                square_footage = 1878,
                lot_size = 8843,
                year_built = 1973,
                assessor_id = '05076-103-0500',
                legal_description = 'CB 5076A BLK 3 LOT 50',
                subdivision = 'CONV A/S CODE',
                zoning = 'RH',
                last_sale_date = '2017-10-19T00:00:00.000Z',
                last_sale_price = 185000,
                hoa = rentcast_client.models.property_records_200_response_inner_hoa.property_records_200_response_inner_hoa(
                    fee = 175, ),
                features = rentcast_client.models.property_records_200_response_inner_features.property_records_200_response_inner_features(
                    architecture_type = 'Contemporary', 
                    cooling = True, 
                    cooling_type = 'Central', 
                    exterior_type = 'Wood', 
                    fireplace = True, 
                    fireplace_type = 'Masonry', 
                    floor_count = 1, 
                    foundation_type = 'Slab / Mat / Raft', 
                    garage = True, 
                    garage_spaces = 2, 
                    garage_type = 'Garage', 
                    heating = True, 
                    heating_type = 'Forced Air', 
                    pool = True, 
                    pool_type = 'Concrete', 
                    roof_type = 'Asphalt', 
                    room_count = 5, 
                    unit_count = 1, 
                    view_type = 'City', ),
                tax_assessments = rentcast_client.models.property_records_200_response_inner_tax_assessments.property_records_200_response_inner_taxAssessments(
                    2019 = rentcast_client.models.property_records_200_response_inner_tax_assessments_2019.property_records_200_response_inner_taxAssessments_2019(
                        year = 2019, 
                        value = 135430, 
                        land = 23450, 
                        improvements = 111980, ), 
                    2020 = rentcast_client.models.property_records_200_response_inner_tax_assessments_2020.property_records_200_response_inner_taxAssessments_2020(
                        year = 2020, 
                        value = 142610, 
                        land = 23450, 
                        improvements = 119160, ), 
                    2021 = rentcast_client.models.property_records_200_response_inner_tax_assessments_2021.property_records_200_response_inner_taxAssessments_2021(
                        year = 2021, 
                        value = 163440, 
                        land = 45050, 
                        improvements = 118390, ), 
                    2022 = rentcast_client.models.property_records_200_response_inner_tax_assessments_2022.property_records_200_response_inner_taxAssessments_2022(
                        year = 2022, 
                        value = 197600, 
                        land = 49560, 
                        improvements = 148040, ), 
                    2023 = rentcast_client.models.property_records_200_response_inner_tax_assessments_2023.property_records_200_response_inner_taxAssessments_2023(
                        year = 2023, 
                        value = 225790, 
                        land = 59380, 
                        improvements = 166410, ), ),
                property_taxes = rentcast_client.models.property_records_200_response_inner_property_taxes.property_records_200_response_inner_propertyTaxes(
                    2019 = rentcast_client.models.property_records_200_response_inner_property_taxes_2019.property_records_200_response_inner_propertyTaxes_2019(
                        year = 2019, 
                        total = 2984, ), 
                    2020 = rentcast_client.models.property_records_200_response_inner_property_taxes_2020.property_records_200_response_inner_propertyTaxes_2020(
                        year = 2020, 
                        total = 3023, ), 
                    2021 = rentcast_client.models.property_records_200_response_inner_property_taxes_2021.property_records_200_response_inner_propertyTaxes_2021(
                        year = 2021, 
                        total = 3455, ), 
                    2022 = rentcast_client.models.property_records_200_response_inner_property_taxes_2022.property_records_200_response_inner_propertyTaxes_2022(
                        year = 2022, 
                        total = 4091, ), 
                    2023 = rentcast_client.models.property_records_200_response_inner_property_taxes_2023.property_records_200_response_inner_propertyTaxes_2023(
                        year = 2023, 
                        total = 4201, ), ),
                history = rentcast_client.models.property_records_200_response_inner_history.property_records_200_response_inner_history(
                    2004_06_16 = rentcast_client.models.property_records_200_response_inner_history_2004_06_16.property_records_200_response_inner_history_2004_06_16(
                        event = 'Sale', 
                        date = '2004-06-16T00:00:00.000Z', 
                        price = 95000, ), 
                    2017_10_19 = rentcast_client.models.property_records_200_response_inner_history_2017_10_19.property_records_200_response_inner_history_2017_10_19(
                        event = 'Sale', 
                        date = '2017-10-19T00:00:00.000Z', 
                        price = 185000, ), ),
                owner = rentcast_client.models.property_records_200_response_inner_owner.property_records_200_response_inner_owner(
                    names = [
                        'Michael Smith'
                        ], 
                    type = 'Individual', 
                    mailing_address = rentcast_client.models.property_records_200_response_inner_owner_mailing_address.property_records_200_response_inner_owner_mailingAddress(
                        id = '149-Weaver-Blvd,---264,-Weaverville,-NC-28787', 
                        formatted_address = '149 Weaver Blvd, # 264, Weaverville, NC 28787', 
                        address_line1 = '149 Weaver Blvd', 
                        address_line2 = '# 264', 
                        city = 'Weaverville', 
                        state = 'NC', 
                        zip_code = '28787', ), ),
                owner_occupied = False
            )
        else:
            return RentcastPropertyRecords200ResponseInner(
        )
        """

    def testRentcastPropertyRecords200ResponseInner(self):
        """Test RentcastPropertyRecords200ResponseInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
