# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.api.default_rentcast import DefaultRentcast


class TestDefaultRentcast(unittest.IsolatedAsyncioTestCase):
    """DefaultRentcast unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = DefaultRentcast()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_market_statistics(self) -> None:
        """Test case for market_statistics

        Market Statistics
        """
        pass

    async def test_property_record_by_id(self) -> None:
        """Test case for property_record_by_id

        Property Record by Id
        """
        pass

    async def test_property_records(self) -> None:
        """Test case for property_records

        Property Records
        """
        pass

    async def test_property_records_random(self) -> None:
        """Test case for property_records_random

        Random Property Records
        """
        pass

    async def test_rent_estimate_long_term(self) -> None:
        """Test case for rent_estimate_long_term

        Rent Estimate
        """
        pass

    async def test_rental_listing_long_term_by_id(self) -> None:
        """Test case for rental_listing_long_term_by_id

        Rental Listing by Id
        """
        pass

    async def test_rental_listings_long_term(self) -> None:
        """Test case for rental_listings_long_term

        Rental Listings
        """
        pass

    async def test_sale_listing_by_id(self) -> None:
        """Test case for sale_listing_by_id

        Sale Listing by Id
        """
        pass

    async def test_sale_listings(self) -> None:
        """Test case for sale_listings

        Sale Listings
        """
        pass

    async def test_value_estimate(self) -> None:
        """Test case for value_estimate

        Value Estimate
        """
        pass


if __name__ == '__main__':
    unittest.main()
