# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_market_statistics200_response_sale_data_history202409_data_by_bedrooms_inner import RentcastMarketStatistics200ResponseSaleDataHistory202409DataByBedroomsInner

class TestRentcastMarketStatistics200ResponseSaleDataHistory202409DataByBedroomsInner(unittest.TestCase):
    """RentcastMarketStatistics200ResponseSaleDataHistory202409DataByBedroomsInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastMarketStatistics200ResponseSaleDataHistory202409DataByBedroomsInner:
        """Test RentcastMarketStatistics200ResponseSaleDataHistory202409DataByBedroomsInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastMarketStatistics200ResponseSaleDataHistory202409DataByBedroomsInner`
        """
        model = RentcastMarketStatistics200ResponseSaleDataHistory202409DataByBedroomsInner()
        if include_optional:
            return RentcastMarketStatistics200ResponseSaleDataHistory202409DataByBedroomsInner(
                bedrooms = 1,
                average_price = 188475,
                median_price = 160000,
                min_price = 147900,
                max_price = 237000,
                average_price_per_square_foot = 243.02,
                median_price_per_square_foot = 199.75,
                min_price_per_square_foot = 184.88,
                max_price_per_square_foot = 342.62,
                average_square_footage = 795,
                median_square_footage = 800,
                min_square_footage = 610,
                max_square_footage = 968,
                average_days_on_market = 115,
                median_days_on_market = 56,
                min_days_on_market = 6,
                max_days_on_market = 300,
                new_listings = 1,
                total_listings = 4
            )
        else:
            return RentcastMarketStatistics200ResponseSaleDataHistory202409DataByBedroomsInner(
        )
        """

    def testRentcastMarketStatistics200ResponseSaleDataHistory202409DataByBedroomsInner(self):
        """Test RentcastMarketStatistics200ResponseSaleDataHistory202409DataByBedroomsInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
