# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history202507_data_by_property_type_inner import RentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner

class TestRentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner(unittest.TestCase):
    """RentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner:
        """Test RentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner`
        """
        model = RentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner()
        if include_optional:
            return RentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner(
                property_type = 'Apartment',
                average_rent = 1098,
                median_rent = 1025,
                min_rent = 875,
                max_rent = 1835,
                average_rent_per_square_foot = 1.25,
                median_rent_per_square_foot = 1.1,
                min_rent_per_square_foot = 1.05,
                max_rent_per_square_foot = 2.03,
                average_square_footage = 911,
                median_square_footage = 950,
                min_square_footage = 629,
                max_square_footage = 1294,
                average_days_on_market = 58.59,
                median_days_on_market = 1,
                min_days_on_market = 1,
                max_days_on_market = 210,
                new_listings = 14,
                total_listings = 24
            )
        else:
            return RentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner(
        )
        """

    def testRentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner(self):
        """Test RentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
