# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_rental_listings_long_term200_response_inner_history20240918 import RentcastRentalListingsLongTerm200ResponseInnerHistory20240918

class TestRentcastRentalListingsLongTerm200ResponseInnerHistory20240918(unittest.TestCase):
    """RentcastRentalListingsLongTerm200ResponseInnerHistory20240918 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastRentalListingsLongTerm200ResponseInnerHistory20240918:
        """Test RentcastRentalListingsLongTerm200ResponseInnerHistory20240918
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastRentalListingsLongTerm200ResponseInnerHistory20240918`
        """
        model = RentcastRentalListingsLongTerm200ResponseInnerHistory20240918()
        if include_optional:
            return RentcastRentalListingsLongTerm200ResponseInnerHistory20240918(
                event = 'Rental Listing',
                price = 2200,
                listing_type = 'Standard',
                listed_date = '2024-09-18T00:00:00.000Z',
                removed_date = None,
                days_on_market = 13
            )
        else:
            return RentcastRentalListingsLongTerm200ResponseInnerHistory20240918(
        )
        """

    def testRentcastRentalListingsLongTerm200ResponseInnerHistory20240918(self):
        """Test RentcastRentalListingsLongTerm200ResponseInnerHistory20240918"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
