# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history202507 import RentcastMarketStatistics200ResponseRentalDataHistory202507

class TestRentcastMarketStatistics200ResponseRentalDataHistory202507(unittest.TestCase):
    """RentcastMarketStatistics200ResponseRentalDataHistory202507 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastMarketStatistics200ResponseRentalDataHistory202507:
        """Test RentcastMarketStatistics200ResponseRentalDataHistory202507
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastMarketStatistics200ResponseRentalDataHistory202507`
        """
        model = RentcastMarketStatistics200ResponseRentalDataHistory202507()
        if include_optional:
            return RentcastMarketStatistics200ResponseRentalDataHistory202507(
                var_date = '2025-07-01T00:00:00.000Z',
                average_rent = 1417,
                median_rent = 1350,
                min_rent = 400,
                max_rent = 3200,
                average_rent_per_square_foot = 1.32,
                median_rent_per_square_foot = 1.28,
                min_rent_per_square_foot = 0.88,
                max_rent_per_square_foot = 2.04,
                average_square_footage = 1136,
                median_square_footage = 1024,
                min_square_footage = 590,
                max_square_footage = 2672,
                average_days_on_market = 34.06,
                median_days_on_market = 1,
                min_days_on_market = 1,
                max_days_on_market = 321,
                new_listings = 46,
                total_listings = 94,
                data_by_property_type = [
                    rentcast_client.models.market_statistics_200_response_rental_data_history_2025_07_data_by_property_type_inner.market_statistics_200_response_rentalData_history_2025_07_dataByPropertyType_inner(
                        property_type = 'Apartment', 
                        average_rent = 1098, 
                        median_rent = 1025, 
                        min_rent = 875, 
                        max_rent = 1835, 
                        average_rent_per_square_foot = 1.25, 
                        median_rent_per_square_foot = 1.1, 
                        min_rent_per_square_foot = 1.05, 
                        max_rent_per_square_foot = 2.03, 
                        average_square_footage = 911, 
                        median_square_footage = 950, 
                        min_square_footage = 629, 
                        max_square_footage = 1294, 
                        average_days_on_market = 58.59, 
                        median_days_on_market = 1, 
                        min_days_on_market = 1, 
                        max_days_on_market = 210, 
                        new_listings = 14, 
                        total_listings = 24, )
                    ],
                data_by_bedrooms = [
                    rentcast_client.models.market_statistics_200_response_rental_data_history_2025_07_data_by_bedrooms_inner.market_statistics_200_response_rentalData_history_2025_07_dataByBedrooms_inner(
                        bedrooms = 1, 
                        average_rent = 926, 
                        median_rent = 945, 
                        min_rent = 400, 
                        max_rent = 1299, 
                        average_rent_per_square_foot = 1.49, 
                        median_rent_per_square_foot = 1.34, 
                        min_rent_per_square_foot = 1, 
                        max_rent_per_square_foot = 2.03, 
                        average_square_footage = 686, 
                        median_square_footage = 650, 
                        min_square_footage = 590, 
                        max_square_footage = 800, 
                        average_days_on_market = 104.77, 
                        median_days_on_market = 107, 
                        min_days_on_market = 1, 
                        max_days_on_market = 321, 
                        new_listings = 1, 
                        total_listings = 15, )
                    ]
            )
        else:
            return RentcastMarketStatistics200ResponseRentalDataHistory202507(
        )
        """

    def testRentcastMarketStatistics200ResponseRentalDataHistory202507(self):
        """Test RentcastMarketStatistics200ResponseRentalDataHistory202507"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
