# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_property_records200_response_inner_history import RentcastPropertyRecords200ResponseInnerHistory

class TestRentcastPropertyRecords200ResponseInnerHistory(unittest.TestCase):
    """RentcastPropertyRecords200ResponseInnerHistory unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastPropertyRecords200ResponseInnerHistory:
        """Test RentcastPropertyRecords200ResponseInnerHistory
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastPropertyRecords200ResponseInnerHistory`
        """
        model = RentcastPropertyRecords200ResponseInnerHistory()
        if include_optional:
            return RentcastPropertyRecords200ResponseInnerHistory(
                var_2004_06_16 = rentcast_client.models.property_records_200_response_inner_history_2004_06_16.property_records_200_response_inner_history_2004_06_16(
                    event = 'Sale', 
                    date = '2004-06-16T00:00:00.000Z', 
                    price = 95000, ),
                var_2017_10_19 = rentcast_client.models.property_records_200_response_inner_history_2017_10_19.property_records_200_response_inner_history_2017_10_19(
                    event = 'Sale', 
                    date = '2017-10-19T00:00:00.000Z', 
                    price = 185000, )
            )
        else:
            return RentcastPropertyRecords200ResponseInnerHistory(
        )
        """

    def testRentcastPropertyRecords200ResponseInnerHistory(self):
        """Test RentcastPropertyRecords200ResponseInnerHistory"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
