# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_market_statistics200_response_sale_data_history202506 import RentcastMarketStatistics200ResponseSaleDataHistory202506

class TestRentcastMarketStatistics200ResponseSaleDataHistory202506(unittest.TestCase):
    """RentcastMarketStatistics200ResponseSaleDataHistory202506 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastMarketStatistics200ResponseSaleDataHistory202506:
        """Test RentcastMarketStatistics200ResponseSaleDataHistory202506
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastMarketStatistics200ResponseSaleDataHistory202506`
        """
        model = RentcastMarketStatistics200ResponseSaleDataHistory202506()
        if include_optional:
            return RentcastMarketStatistics200ResponseSaleDataHistory202506(
                var_date = '2025-06-01T00:00:00.000Z',
                average_price = 348402,
                median_price = 290000,
                min_price = 8899,
                max_price = 2530000,
                average_price_per_square_foot = 198.98,
                median_price_per_square_foot = 174.94,
                min_price_per_square_foot = 54,
                max_price_per_square_foot = 962.5,
                average_square_footage = 1712,
                median_square_footage = 1587,
                min_square_footage = 792,
                max_square_footage = 6000,
                average_days_on_market = 76.89,
                median_days_on_market = 54,
                min_days_on_market = 2,
                max_days_on_market = 348,
                new_listings = 47,
                total_listings = 263,
                data_by_property_type = [
                    rentcast_client.models.market_statistics_200_response_sale_data_history_2025_06_data_by_property_type_inner.market_statistics_200_response_saleData_history_2025_06_dataByPropertyType_inner(
                        property_type = 'Condo', 
                        average_price = 380983, 
                        median_price = 125000, 
                        min_price = 105000, 
                        max_price = 1599000, 
                        average_price_per_square_foot = 166.94, 
                        median_price_per_square_foot = 129.63, 
                        min_price_per_square_foot = 119.07, 
                        max_price_per_square_foot = 357.48, 
                        average_square_footage = 1630, 
                        median_square_footage = 1049, 
                        min_square_footage = 810, 
                        max_square_footage = 4473, 
                        average_days_on_market = 92.83, 
                        median_days_on_market = 54, 
                        min_days_on_market = 53, 
                        max_days_on_market = 220, 
                        new_listings = 0, 
                        total_listings = 6, )
                    ],
                data_by_bedrooms = [
                    rentcast_client.models.market_statistics_200_response_sale_data_history_2025_06_data_by_bedrooms_inner.market_statistics_200_response_saleData_history_2025_06_dataByBedrooms_inner(
                        bedrooms = 0, 
                        average_price = 499900, 
                        median_price = 499900, 
                        min_price = 499900, 
                        max_price = 499900, 
                        average_price_per_square_foot = 83.32, 
                        median_price_per_square_foot = 83.32, 
                        min_price_per_square_foot = 83.32, 
                        max_price_per_square_foot = 83.32, 
                        average_square_footage = 6000, 
                        median_square_footage = 6000, 
                        min_square_footage = 6000, 
                        max_square_footage = 6000, 
                        average_days_on_market = 24, 
                        median_days_on_market = 24, 
                        min_days_on_market = 24, 
                        max_days_on_market = 24, 
                        new_listings = 1, 
                        total_listings = 1, )
                    ]
            )
        else:
            return RentcastMarketStatistics200ResponseSaleDataHistory202506(
        )
        """

    def testRentcastMarketStatistics200ResponseSaleDataHistory202506(self):
        """Test RentcastMarketStatistics200ResponseSaleDataHistory202506"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
